
/***************************************************

		miscMath.h

   Declarations for the functions in miscMath.c.

***************************************************/


#include <math.h>

#define TWOPI		( M_PI * 2.0 )

#define XFLAG		0
#define YFLAG		1

#define abs(x) ((x) < 0 ? -(x): (x)) 

/* data types */

struct aPoint{
   double x;
   double y;
};

typedef struct aPoint point;


/* The basic line structure.  DO NOT set the values in these
   structures manually.  Use the supplied functions!  */

struct aLine{		
   struct aPoint *p1;	/*  the two points that define the line */
   struct aPoint *p2;
   double slope;	/*  slope intercept form of the line */
   double intercept;
   double A;		/*  standard form of the line */
   double B;		/*  Ax + By + C = 0           */
   double C;
};

typedef struct aLine line;

/* functions available */


extern point  *allocPoint();
extern void   freePoint( point *thePoint );
extern double distance( point *p1, point *p2 );

extern line   *allocLine();
extern void   freeLine( line *theLine );

extern void   solveLineCartesian( point *point1, point *point2, line *theLine );
extern void   solveLinePointSlope( point *point1, double slope, line *theLine );

extern void   evalLine( line *theLine, double value, int axisFlag, point *thePoint );
extern double evalLineFx( double x, line *theLine );

extern double intersectionPoint( line *line1, line *line2 );
extern int    linesIntersect( line *line1, line *line2 );

extern double sameSide( line *theLine, point *point1, point *point2 );
extern double pointLineSeparation( point *pt, line *line );

extern void   cartesianToPolar( double x, double y, double *radius, double *angle );
